@@ -232,11 +232,13 @@ LinternaMagica.prototype.extract_youtube_fmt_url_map = function()
 	    var link = fmt[url].match(/(url|conn)=([^&]+)/);
 	    var fmt_id = fmt[url].match(/itag=([0-9]+)/);
 	    var sig = fmt[url].replace(/\\u0026/g, '&').match(/sig=[^&]+/);
+	    var short_sig = fmt[url].replace(/\\u0026/g, '&').match(/&s=[^&]+/);
+
 	    sig = sig ? sig[sig.length-1].replace(/sig/,'signature') : '';
 
 	    // Bug 39402. Some links have the signature in the s=<SIG>
 	    // format. For example when they are oppened from Canada
-	    if (!sig)
+	    if (short_sig)
 	    {
 		this.sites["youtube.com"].encrypted_signature = 1;
 		sig = "";
@@ -478,12 +480,15 @@ function(object_data)
 LinternaMagica.prototype.sites["youtube.com"].player_stream_ended_action =
 function()
 {
-    var playlist = document.getElementById("watch7-playlist-tray");
-    var autoplay = document.getElementById("watch7-playlist-bar-autoplay-button");
-    var current_song =
-	this.get_first_element_by_class("playlist-bar-item-playing", playlist);
+    var playlist = document.getElementById("watch-appbar-playlist");
+    var autoplay =
+	this.get_first_element_by_class("toggle-autoplay", playlist);
 
-    var shuffle = document.getElementById("watch7-playlist-bar-shuffle-button");
+    var current_song =
+	this.get_first_element_by_class("currently-playing", playlist);
+
+    var shuffle =
+	this.get_first_element_by_class("shuffle-playlist", playlist);
 
     var next_song = null;
 
@@ -661,6 +666,13 @@ function(object_data)
 	}
     }
 
+    // FIX Displacement of the sidebar in playlists.
+    var watch7_sidebar = document.getElementById("watch7-sidebar");
+    if (watch7_sidebar)
+    {
+	watch7_sidebar.style.setProperty("margin-top", "-429px", "important");
+    }
+
     if (document.getElementById("playnav-playview"))
     {
 	// In channels/user pages in YouTube the web controlls are
